@@ -8,7 +8,7 @@ testthat::test_that("guess_provider",{
   a <- guess_provider("a4")
   expect_equal(a$name, "BioConductor")
   ## An R package
-  a <- guess_provider("Matrix")
+  a <- guess_provider("lattice")
   expect_equal(a$name, "Comprehensive R Archive Network (CRAN)")
 })
 
@@ -94,9 +94,9 @@ test_that("fileSize", {
 
 })
 
-test_that("add_github_topics",{
-  skip_if_offline()
+test_that("add_github_topics", {
   skip_on_cran()
+  skip_if_offline()
   testthat::skip_if_not(nzchar(Sys.getenv("GITHUB_PAT")))
 
   cm <- NULL
